/********************************************************************************
** Form generated from reading UI file 'nameanddatasourcedialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NAMEANDDATASOURCEDIALOG_H
#define UI_NAMEANDDATASOURCEDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_NameAndDataSourceDialog
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *nameLabel;
    QLineEdit *nameEdit;
    QLabel *sourceLabel;
    QComboBox *sourceCombo;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *NameAndDataSourceDialog)
    {
        if (NameAndDataSourceDialog->objectName().isEmpty())
            NameAndDataSourceDialog->setObjectName("NameAndDataSourceDialog");
        NameAndDataSourceDialog->resize(400, 300);
        verticalLayout = new QVBoxLayout(NameAndDataSourceDialog);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setSizeConstraint(QLayout::SetFixedSize);
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        nameLabel = new QLabel(NameAndDataSourceDialog);
        nameLabel->setObjectName("nameLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, nameLabel);

        nameEdit = new QLineEdit(NameAndDataSourceDialog);
        nameEdit->setObjectName("nameEdit");
        nameEdit->setMinimumSize(QSize(200, 0));

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, nameEdit);

        sourceLabel = new QLabel(NameAndDataSourceDialog);
        sourceLabel->setObjectName("sourceLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, sourceLabel);

        sourceCombo = new QComboBox(NameAndDataSourceDialog);
        sourceCombo->setObjectName("sourceCombo");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, sourceCombo);


        verticalLayout->addLayout(formLayout);

        buttonBox = new QDialogButtonBox(NameAndDataSourceDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(NameAndDataSourceDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, NameAndDataSourceDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, NameAndDataSourceDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(NameAndDataSourceDialog);
    } // setupUi

    void retranslateUi(QDialog *NameAndDataSourceDialog)
    {
        NameAndDataSourceDialog->setWindowTitle(tr2i18n("Add a project", nullptr));
        nameLabel->setText(tr2i18n("Name", nullptr));
        sourceLabel->setText(tr2i18n("Source", nullptr));
    } // retranslateUi

};

namespace Ui {
    class NameAndDataSourceDialog: public Ui_NameAndDataSourceDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // NAMEANDDATASOURCEDIALOG_H

