/****************************************************************************
** Meta object code from reading C++ file 'task.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../zanshin-26.08.0/src/domain/task.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'task.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Domain4TaskE_t {};
} // unnamed namespace

template <> constexpr inline auto Domain::Task::qt_create_metaobjectdata<qt_meta_tag_ZN6Domain4TaskE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Domain::Task",
        "textChanged",
        "",
        "text",
        "titleChanged",
        "title",
        "runningChanged",
        "isRunning",
        "doneChanged",
        "isDone",
        "doneDateChanged",
        "doneDate",
        "startDateChanged",
        "startDate",
        "dueDateChanged",
        "dueDate",
        "recurrenceChanged",
        "Domain::Task::Recurrence",
        "recurrence",
        "attachmentsChanged",
        "Domain::Task::Attachments",
        "attachments",
        "setText",
        "setTitle",
        "setRunning",
        "running",
        "setDone",
        "done",
        "setDoneDate",
        "setStartDate",
        "setDueDate",
        "setRecurrence",
        "setAttachments",
        "attachements",
        "Recurrence",
        "NoRecurrence",
        "RecursDaily",
        "RecursWeekly",
        "RecursMonthly",
        "RecursYearly"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'textChanged'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'runningChanged'
        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'doneChanged'
        QtMocHelpers::SignalData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Signal 'doneDateChanged'
        QtMocHelpers::SignalData<void(const QDate &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 11 },
        }}),
        // Signal 'startDateChanged'
        QtMocHelpers::SignalData<void(const QDate &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 13 },
        }}),
        // Signal 'dueDateChanged'
        QtMocHelpers::SignalData<void(const QDate &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 15 },
        }}),
        // Signal 'recurrenceChanged'
        QtMocHelpers::SignalData<void(Domain::Task::Recurrence)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Signal 'attachmentsChanged'
        QtMocHelpers::SignalData<void(const Domain::Task::Attachments &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'setText'
        QtMocHelpers::SlotData<void(const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'setTitle'
        QtMocHelpers::SlotData<void(const QString &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'setRunning'
        QtMocHelpers::SlotData<void(bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'setDone'
        QtMocHelpers::SlotData<void(bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Slot 'setDoneDate'
        QtMocHelpers::SlotData<void(const QDate &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 11 },
        }}),
        // Slot 'setStartDate'
        QtMocHelpers::SlotData<void(const QDate &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 13 },
        }}),
        // Slot 'setDueDate'
        QtMocHelpers::SlotData<void(const QDate &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 15 },
        }}),
        // Slot 'setRecurrence'
        QtMocHelpers::SlotData<void(Domain::Task::Recurrence)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'setAttachments'
        QtMocHelpers::SlotData<void(const Domain::Task::Attachments &)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'text'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'title'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'running'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'done'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'startDate'
        QtMocHelpers::PropertyData<QDate>(13, QMetaType::QDate, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'dueDate'
        QtMocHelpers::PropertyData<QDate>(15, QMetaType::QDate, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'recurrence'
        QtMocHelpers::PropertyData<Domain::Task::Recurrence>(18, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'attachements'
        QtMocHelpers::PropertyData<Domain::Task::Attachments>(33, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 8),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Recurrence'
        QtMocHelpers::EnumData<enum Recurrence>(34, 34, QMC::EnumFlags{}).add({
            {   35, Recurrence::NoRecurrence },
            {   36, Recurrence::RecursDaily },
            {   37, Recurrence::RecursWeekly },
            {   38, Recurrence::RecursMonthly },
            {   39, Recurrence::RecursYearly },
        }),
    };
    return QtMocHelpers::metaObjectData<Task, qt_meta_tag_ZN6Domain4TaskE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Domain::Task::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Domain4TaskE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Domain4TaskE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Domain4TaskE_t>.metaTypes,
    nullptr
} };

void Domain::Task::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Task *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->textChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->titleChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->runningChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->doneChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->doneDateChanged((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 5: _t->startDateChanged((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 6: _t->dueDateChanged((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 7: _t->recurrenceChanged((*reinterpret_cast<std::add_pointer_t<Domain::Task::Recurrence>>(_a[1]))); break;
        case 8: _t->attachmentsChanged((*reinterpret_cast<std::add_pointer_t<Domain::Task::Attachments>>(_a[1]))); break;
        case 9: _t->setText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->setTitle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->setRunning((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->setDone((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->setDoneDate((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 14: _t->setStartDate((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 15: _t->setDueDate((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 16: _t->setRecurrence((*reinterpret_cast<std::add_pointer_t<Domain::Task::Recurrence>>(_a[1]))); break;
        case 17: _t->setAttachments((*reinterpret_cast<std::add_pointer_t<Domain::Task::Attachments>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Domain::Task::Attachments >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Domain::Task::Attachments >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Task::*)(const QString & )>(_a, &Task::textChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Task::*)(const QString & )>(_a, &Task::titleChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Task::*)(bool )>(_a, &Task::runningChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Task::*)(bool )>(_a, &Task::doneChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Task::*)(const QDate & )>(_a, &Task::doneDateChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Task::*)(const QDate & )>(_a, &Task::startDateChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Task::*)(const QDate & )>(_a, &Task::dueDateChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Task::*)(Domain::Task::Recurrence )>(_a, &Task::recurrenceChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Task::*)(const Domain::Task::Attachments & )>(_a, &Task::attachmentsChanged, 8))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 7:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Domain::Task::Attachments >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->text(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isRunning(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isDone(); break;
        case 4: *reinterpret_cast<QDate*>(_v) = _t->startDate(); break;
        case 5: *reinterpret_cast<QDate*>(_v) = _t->dueDate(); break;
        case 6: *reinterpret_cast<Domain::Task::Recurrence*>(_v) = _t->recurrence(); break;
        case 7: *reinterpret_cast<Domain::Task::Attachments*>(_v) = _t->attachments(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setText(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setTitle(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setRunning(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setDone(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setStartDate(*reinterpret_cast<QDate*>(_v)); break;
        case 5: _t->setDueDate(*reinterpret_cast<QDate*>(_v)); break;
        case 6: _t->setRecurrence(*reinterpret_cast<Domain::Task::Recurrence*>(_v)); break;
        case 7: _t->setAttachments(*reinterpret_cast<Domain::Task::Attachments*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Domain::Task::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Domain::Task::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Domain4TaskE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Domain::Task::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void Domain::Task::textChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Domain::Task::titleChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Domain::Task::runningChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Domain::Task::doneChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Domain::Task::doneDateChanged(const QDate & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Domain::Task::startDateChanged(const QDate & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Domain::Task::dueDateChanged(const QDate & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Domain::Task::recurrenceChanged(Domain::Task::Recurrence _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Domain::Task::attachmentsChanged(const Domain::Task::Attachments & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}
QT_WARNING_POP
