/*
 * SPDX-FileCopyrightText: 2015 Theo Vaucher <theo.vaucher@gmail.com>
 * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */


#ifndef UTILS_DATETIME
#define UTILS_DATETIME

class QDateTime;
class QDate;

namespace Utils {

namespace DateTime
{
    QDate currentDate();
}

}

#endif // UTILS_DATETIME
