/****************************************************************************
** Meta object code from reading C++ file 'pagemodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../zanshin-26.08.0/src/presentation/pagemodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'pagemodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12Presentation9PageModelE_t {};
} // unnamed namespace

template <> constexpr inline auto Presentation::PageModel::qt_create_metaobjectdata<qt_meta_tag_ZN12Presentation9PageModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Presentation::PageModel",
        "addItem",
        "Domain::Task::Ptr",
        "",
        "title",
        "QModelIndex",
        "parentIndex",
        "removeItem",
        "index",
        "promoteItem",
        "centralListModel",
        "QAbstractItemModel*",
        "TaskExtraPart",
        "None",
        "DataSource",
        "Project",
        "Contexts",
        "TaskExtraParts"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'addItem'
        QtMocHelpers::SlotData<Domain::Task::Ptr(const QString &, const QModelIndex &)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Slot 'addItem'
        QtMocHelpers::SlotData<Domain::Task::Ptr(const QString &)>(1, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 2, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'removeItem'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(7, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 8 },
        }}),
        // Slot 'promoteItem'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(9, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'centralListModel'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'TaskExtraPart'
        QtMocHelpers::EnumData<enum TaskExtraPart>(12, 12, QMC::EnumIsScoped).add({
            {   13, TaskExtraPart::None },
            {   14, TaskExtraPart::DataSource },
            {   15, TaskExtraPart::Project },
            {   16, TaskExtraPart::Contexts },
        }),
        // flag 'TaskExtraParts'
        QtMocHelpers::EnumData<TaskExtraParts>(17, 12, QMC::EnumIsFlag | QMC::EnumIsScoped).add({
            {   13, TaskExtraPart::None },
            {   14, TaskExtraPart::DataSource },
            {   15, TaskExtraPart::Project },
            {   16, TaskExtraPart::Contexts },
        }),
    };
    return QtMocHelpers::metaObjectData<PageModel, qt_meta_tag_ZN12Presentation9PageModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Presentation::PageModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Presentation9PageModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Presentation9PageModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12Presentation9PageModelE_t>.metaTypes,
    nullptr
} };

void Presentation::PageModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PageModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { Domain::Task::Ptr _r = _t->addItem((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Domain::Task::Ptr*>(_a[0]) = std::move(_r); }  break;
        case 1: { Domain::Task::Ptr _r = _t->addItem((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Domain::Task::Ptr*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->removeItem((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 3: _t->promoteItem((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractItemModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->centralListModel(); break;
        default: break;
        }
    }
}

const QMetaObject *Presentation::PageModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Presentation::PageModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Presentation9PageModelE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "ErrorHandlingModelBase"))
        return static_cast< ErrorHandlingModelBase*>(this);
    return QObject::qt_metacast(_clname);
}

int Presentation::PageModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
