/********************************************************************************
** Form generated from reading UI file 'editorview.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EDITORVIEW_H
#define UI_EDITORVIEW_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListView>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KDateComboBox"

QT_BEGIN_NAMESPACE

class Ui_EditorView
{
public:
    QAction *actionEditor;
    QVBoxLayout *layout;
    QPlainTextEdit *textEdit;
    QWidget *taskGroup;
    QGridLayout *gridLayout;
    QLabel *dueDateLabel;
    QComboBox *recurrenceCombo;
    QHBoxLayout *doneLayout;
    QCheckBox *doneButton;
    QHBoxLayout *horizontalLayout_3;
    QSpacerItem *horizontalSpacer;
    QToolButton *addAttachmentButton;
    QToolButton *removeAttachmentButton;
    QHBoxLayout *horizontalLayout;
    KDateComboBox *startDateEdit;
    QPushButton *startTodayButton;
    QLabel *recurrenceLabel;
    KDateComboBox *dueDateEdit;
    QLabel *startDateLabel;
    QListView *attachmentList;

    void setupUi(QWidget *EditorView)
    {
        if (EditorView->objectName().isEmpty())
            EditorView->setObjectName("EditorView");
        EditorView->resize(343, 448);
        actionEditor = new QAction(EditorView);
        actionEditor->setObjectName("actionEditor");
        layout = new QVBoxLayout(EditorView);
        layout->setSpacing(6);
        layout->setContentsMargins(11, 11, 11, 11);
        layout->setObjectName("layout");
        layout->setContentsMargins(-1, -1, -1, 6);
        textEdit = new QPlainTextEdit(EditorView);
        textEdit->setObjectName("textEdit");

        layout->addWidget(textEdit);

        taskGroup = new QWidget(EditorView);
        taskGroup->setObjectName("taskGroup");
        gridLayout = new QGridLayout(taskGroup);
        gridLayout->setSpacing(6);
        gridLayout->setContentsMargins(11, 11, 11, 11);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        dueDateLabel = new QLabel(taskGroup);
        dueDateLabel->setObjectName("dueDateLabel");
        dueDateLabel->setMargin(4);

        gridLayout->addWidget(dueDateLabel, 3, 0, 1, 1);

        recurrenceCombo = new QComboBox(taskGroup);
        recurrenceCombo->setObjectName("recurrenceCombo");

        gridLayout->addWidget(recurrenceCombo, 4, 1, 1, 1);

        doneLayout = new QHBoxLayout();
        doneLayout->setSpacing(6);
        doneLayout->setObjectName("doneLayout");
        doneLayout->setContentsMargins(3, -1, -1, -1);
        doneButton = new QCheckBox(taskGroup);
        doneButton->setObjectName("doneButton");

        doneLayout->addWidget(doneButton);


        gridLayout->addLayout(doneLayout, 5, 0, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(6);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer);

        addAttachmentButton = new QToolButton(taskGroup);
        addAttachmentButton->setObjectName("addAttachmentButton");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("list-add");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        addAttachmentButton->setIcon(icon);
        addAttachmentButton->setAutoRaise(true);

        horizontalLayout_3->addWidget(addAttachmentButton);

        removeAttachmentButton = new QToolButton(taskGroup);
        removeAttachmentButton->setObjectName("removeAttachmentButton");
        QIcon icon1;
        iconThemeName = QString::fromUtf8("list-remove");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        removeAttachmentButton->setIcon(icon1);
        removeAttachmentButton->setAutoRaise(true);

        horizontalLayout_3->addWidget(removeAttachmentButton);


        gridLayout->addLayout(horizontalLayout_3, 1, 1, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(6);
        horizontalLayout->setObjectName("horizontalLayout");
        startDateEdit = new KDateComboBox(taskGroup);
        startDateEdit->setObjectName("startDateEdit");

        horizontalLayout->addWidget(startDateEdit);

        startTodayButton = new QPushButton(taskGroup);
        startTodayButton->setObjectName("startTodayButton");

        horizontalLayout->addWidget(startTodayButton);


        gridLayout->addLayout(horizontalLayout, 2, 1, 1, 1);

        recurrenceLabel = new QLabel(taskGroup);
        recurrenceLabel->setObjectName("recurrenceLabel");
        recurrenceLabel->setMargin(4);

        gridLayout->addWidget(recurrenceLabel, 4, 0, 1, 1);

        dueDateEdit = new KDateComboBox(taskGroup);
        dueDateEdit->setObjectName("dueDateEdit");

        gridLayout->addWidget(dueDateEdit, 3, 1, 1, 1);

        startDateLabel = new QLabel(taskGroup);
        startDateLabel->setObjectName("startDateLabel");
        startDateLabel->setMargin(4);

        gridLayout->addWidget(startDateLabel, 2, 0, 1, 1);

        attachmentList = new QListView(taskGroup);
        attachmentList->setObjectName("attachmentList");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(attachmentList->sizePolicy().hasHeightForWidth());
        attachmentList->setSizePolicy(sizePolicy);
        attachmentList->setMaximumSize(QSize(16777215, 100));
        attachmentList->setFlow(QListView::LeftToRight);
        attachmentList->setProperty("isWrapping", QVariant(true));

        gridLayout->addWidget(attachmentList, 0, 0, 1, 2);


        layout->addWidget(taskGroup);

        layout->setStretch(0, 1);
#if QT_CONFIG(shortcut)
        dueDateLabel->setBuddy(dueDateEdit);
        recurrenceLabel->setBuddy(recurrenceCombo);
        startDateLabel->setBuddy(startDateEdit);
#endif // QT_CONFIG(shortcut)

        retranslateUi(EditorView);

        QMetaObject::connectSlotsByName(EditorView);
    } // setupUi

    void retranslateUi(QWidget *EditorView)
    {
        EditorView->setWindowTitle(tr2i18n("Editor", nullptr));
        actionEditor->setText(tr2i18n("Editor", nullptr));
        dueDateLabel->setText(tr2i18n("D&ue Date ", nullptr));
        doneButton->setText(tr2i18n("Done", nullptr));
#if QT_CONFIG(tooltip)
        addAttachmentButton->setToolTip(tr2i18n("Add Attachment...", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        removeAttachmentButton->setToolTip(tr2i18n("Remove Attachment", nullptr));
#endif // QT_CONFIG(tooltip)
        startTodayButton->setText(tr2i18n("Select for &Today", nullptr));
        recurrenceLabel->setText(tr2i18n("&Recurrence", nullptr));
        startDateLabel->setText(tr2i18n("St&art Date", nullptr));
    } // retranslateUi

};

namespace Ui {
    class EditorView: public Ui_EditorView {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EDITORVIEW_H

