/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // zanshin_part.rc
  0x0,0x0,0x1,0x4d,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x6b,0x3,0x1d,0xa,0x0,0x82,0xcf,0x2f,0x1e,0x40,0x73,0x1b,
  0x8c,0x48,0x39,0x8b,0xb2,0x2a,0xed,0x86,0xa6,0x25,0xd,0x16,0x4d,0x6d,0xa0,0x28,
  0xac,0xcb,0x22,0x2,0xdd,0x99,0xca,0x67,0x97,0x34,0x22,0x8f,0x83,0xda,0xe3,0xa0,
  0x86,0xb9,0xf4,0x27,0x8e,0xee,0x3a,0x61,0xfc,0x54,0x72,0x19,0x79,0xad,0xc2,0x66,
  0xfe,0xfd,0x21,0x23,0xf6,0x38,0x96,0xfc,0xd4,0xca,0x41,0x46,0x5b,0xf9,0x4a,0xcd,
  0x2c,0xd3,0x1d,0x69,0xfd,0xcf,0x59,0xce,0x2b,0xf6,0xd3,0xac,0xc3,0xa9,0xab,0xe9,
  0xf2,0xf8,0xb1,0xb2,0xdc,0x94,0xef,0x43,0xad,0x1b,0x6,0x68,0x69,0xc0,0x75,0x5,
  0xb5,0x6f,0xab,0x1d,0x6e,0xf6,0x69,0x26,0xef,0x57,0x57,0xb8,0x90,0xd5,0xb4,0xb5,
  0xce,0xd9,0xe7,0xa6,0x40,0x2c,0x29,0x4a,0xa7,0xa7,0xec,0xa5,0x1d,0x4e,0xd7,0x56,
  0xa,0xb9,0xdf,0x53,0x10,0x9b,0x79,0x15,0xf6,0x38,0xd7,0x44,0xe4,0x95,0x1a,0x7b,
  0x5c,0x12,0x32,0xe2,0x7e,0x97,0xaf,0x86,0x25,0x3f,0xcb,0xc5,0xda,0xc9,0x68,0x2d,
  0xe5,0xf6,0xb8,0xa4,0x9e,0x12,0x24,0x93,0x18,0x11,0x88,0x4,0xc2,0x5e,0xac,0xde,
  0x15,0x62,0x18,0xe3,0x21,0x89,0x28,0x1c,0xb,0x40,0xb,0x33,0x20,0x20,0x48,0x30,
  0x48,0x22,0xba,0xd,0x39,0x44,0x8,0x9b,0x19,0x57,0x1a,0x38,0x60,0x50,0x34,0xe,
  0x3f,0x2,0x3f,0x38,0x54,0x5b,0x60,0x92,0xe0,0xb0,0x8,0x34,0xe,0xe3,0x2a,0x60,
  0x8e,0x1f,0xe2,0x2e,0xae,0x22,0x77,0xb1,0x70,0x24,0xd8,0x91,0xa2,0xdc,0x64,0x6,
  0x5a,0x67,0x29,0xc8,0x0,0xd4,0x0,0xc1,0x79,0x46,0x84,0xaa,0xa8,0x6a,0xc2,0xd4,
  0x67,0x38,0x29,0x8,0x9f,0x37,0x0,0xf0,0xf9,0x81,0x8,0x23,0x9e,0x5,0x6a,0xee,
  0xe2,0xd,0x18,0x5c,0xc,0x58,0x41,0xd4,0x3,0x9,0x89,0x30,0x74,0xbb,0x60,0xcc,
  0x40,0x56,0xa6,0x2d,0xeb,0x14,0x5a,0x14,0xc6,0x42,0x69,0xb1,0x55,0x56,0x9,0x80,
  0x51,0x20,0x99,0x19,0xe0,0x8c,0x42,0xba,0xc4,0x89,0x8,0x78,
  
};

static const unsigned char qt_resource_name[] = {
  // kxmlgui5
  0x0,0x8,
  0xf,0x42,0xe5,0x85,
  0x0,0x6b,
  0x0,0x78,0x0,0x6d,0x0,0x6c,0x0,0x67,0x0,0x75,0x0,0x69,0x0,0x35,
    // zanshin
  0x0,0x7,
  0x0,0x85,0x9f,0xfe,
  0x0,0x7a,
  0x0,0x61,0x0,0x6e,0x0,0x73,0x0,0x68,0x0,0x69,0x0,0x6e,
    // zanshin_part.rc
  0x0,0xf,
  0xd,0xc9,0x7f,0x43,
  0x0,0x7a,
  0x0,0x61,0x0,0x6e,0x0,0x73,0x0,0x68,0x0,0x69,0x0,0x6e,0x0,0x5f,0x0,0x70,0x0,0x61,0x0,0x72,0x0,0x74,0x0,0x2e,0x0,0x72,0x0,0x63,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0xa0,0x1a,0xf1,0x8c,0xe8,
  // :/kxmlgui5
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0xa0,0x1a,0xf1,0x8c,0xe8,
  // :/kxmlgui5/zanshin
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0xa0,0x1a,0xf1,0x8c,0xe8,
  // :/kxmlgui5/zanshin/zanshin_part.rc
  0x0,0x0,0x0,0x2a,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0xa0,0x1a,0xf1,0x8c,0xe8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_kontact_plugins)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_kontact_plugins)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kontact_plugins)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kontact_plugins)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_kontact_plugins)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kontact_plugins)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
