/****************************************************************************
** Meta object code from reading C++ file 'editormodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../zanshin-26.08.0/src/presentation/editormodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'editormodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12Presentation11EditorModelE_t {};
} // unnamed namespace

template <> constexpr inline auto Presentation::EditorModel::qt_create_metaobjectdata<qt_meta_tag_ZN12Presentation11EditorModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Presentation::EditorModel",
        "taskChanged",
        "",
        "Domain::Task::Ptr",
        "task",
        "textChanged",
        "text",
        "titleChanged",
        "title",
        "doneChanged",
        "done",
        "startDateChanged",
        "date",
        "dueDateChanged",
        "due",
        "recurrenceChanged",
        "Domain::Task::Recurrence",
        "recurrence",
        "setText",
        "setTitle",
        "setDone",
        "setStartDate",
        "start",
        "setDueDate",
        "setRecurrence",
        "addAttachment",
        "fileName",
        "removeAttachment",
        "QModelIndex",
        "index",
        "openAttachment",
        "setEditingInProgress",
        "editingInProgress",
        "onTextChanged",
        "onTitleChanged",
        "onDoneChanged",
        "onStartDateChanged",
        "onDueDateChanged",
        "onRecurrenceChanged",
        "save",
        "startDate",
        "dueDate",
        "attachmentModel",
        "QAbstractItemModel*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'taskChanged'
        QtMocHelpers::SignalData<void(const Domain::Task::Ptr &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'textChanged'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'doneChanged'
        QtMocHelpers::SignalData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Signal 'startDateChanged'
        QtMocHelpers::SignalData<void(const QDate &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 12 },
        }}),
        // Signal 'dueDateChanged'
        QtMocHelpers::SignalData<void(const QDate &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 14 },
        }}),
        // Signal 'recurrenceChanged'
        QtMocHelpers::SignalData<void(Domain::Task::Recurrence)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'setText'
        QtMocHelpers::SlotData<void(const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'setTitle'
        QtMocHelpers::SlotData<void(const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'setDone'
        QtMocHelpers::SlotData<void(bool)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Slot 'setStartDate'
        QtMocHelpers::SlotData<void(const QDate &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 22 },
        }}),
        // Slot 'setDueDate'
        QtMocHelpers::SlotData<void(const QDate &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 14 },
        }}),
        // Slot 'setRecurrence'
        QtMocHelpers::SlotData<void(Domain::Task::Recurrence)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'addAttachment'
        QtMocHelpers::SlotData<void(const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'removeAttachment'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'openAttachment'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'setEditingInProgress'
        QtMocHelpers::SlotData<void(bool)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Slot 'onTextChanged'
        QtMocHelpers::SlotData<void(const QString &)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'onTitleChanged'
        QtMocHelpers::SlotData<void(const QString &)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'onDoneChanged'
        QtMocHelpers::SlotData<void(bool)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Slot 'onStartDateChanged'
        QtMocHelpers::SlotData<void(const QDate &)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QDate, 22 },
        }}),
        // Slot 'onDueDateChanged'
        QtMocHelpers::SlotData<void(const QDate &)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QDate, 14 },
        }}),
        // Slot 'onRecurrenceChanged'
        QtMocHelpers::SlotData<void(Domain::Task::Recurrence)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'task'
        QtMocHelpers::PropertyData<Domain::Task::Ptr>(4, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'text'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'title'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'done'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'startDate'
        QtMocHelpers::PropertyData<QDate>(40, QMetaType::QDate, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'dueDate'
        QtMocHelpers::PropertyData<QDate>(41, QMetaType::QDate, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'recurrence'
        QtMocHelpers::PropertyData<Domain::Task::Recurrence>(17, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'attachmentModel'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(42, 0x80000000 | 43, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'editingInProgress'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EditorModel, qt_meta_tag_ZN12Presentation11EditorModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN12Presentation11EditorModelE[] = {
    QMetaObject::SuperData::link<Domain::Task::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject Presentation::EditorModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Presentation11EditorModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Presentation11EditorModelE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN12Presentation11EditorModelE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12Presentation11EditorModelE_t>.metaTypes,
    nullptr
} };

void Presentation::EditorModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EditorModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->taskChanged((*reinterpret_cast<std::add_pointer_t<Domain::Task::Ptr>>(_a[1]))); break;
        case 1: _t->textChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->titleChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->doneChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->startDateChanged((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 5: _t->dueDateChanged((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 6: _t->recurrenceChanged((*reinterpret_cast<std::add_pointer_t<Domain::Task::Recurrence>>(_a[1]))); break;
        case 7: _t->setText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->setTitle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->setDone((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->setStartDate((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 11: _t->setDueDate((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 12: _t->setRecurrence((*reinterpret_cast<std::add_pointer_t<Domain::Task::Recurrence>>(_a[1]))); break;
        case 13: _t->addAttachment((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->removeAttachment((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 15: _t->openAttachment((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 16: _t->setEditingInProgress((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->onTextChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: _t->onTitleChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->onDoneChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->onStartDateChanged((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 21: _t->onDueDateChanged((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 22: _t->onRecurrenceChanged((*reinterpret_cast<std::add_pointer_t<Domain::Task::Recurrence>>(_a[1]))); break;
        case 23: _t->save(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Domain::Task::Ptr >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (EditorModel::*)(const Domain::Task::Ptr & )>(_a, &EditorModel::taskChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditorModel::*)(const QString & )>(_a, &EditorModel::textChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditorModel::*)(const QString & )>(_a, &EditorModel::titleChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditorModel::*)(bool )>(_a, &EditorModel::doneChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditorModel::*)(const QDate & )>(_a, &EditorModel::startDateChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditorModel::*)(const QDate & )>(_a, &EditorModel::dueDateChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditorModel::*)(Domain::Task::Recurrence )>(_a, &EditorModel::recurrenceChanged, 6))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Domain::Task::Ptr >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<Domain::Task::Ptr*>(_v) = _t->task(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->text(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isDone(); break;
        case 4: *reinterpret_cast<QDate*>(_v) = _t->startDate(); break;
        case 5: *reinterpret_cast<QDate*>(_v) = _t->dueDate(); break;
        case 6: *reinterpret_cast<Domain::Task::Recurrence*>(_v) = _t->recurrence(); break;
        case 7: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->attachmentModel(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->editingInProgress(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setTask(*reinterpret_cast<Domain::Task::Ptr*>(_v)); break;
        case 1: _t->setText(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setTitle(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setDone(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setStartDate(*reinterpret_cast<QDate*>(_v)); break;
        case 5: _t->setDueDate(*reinterpret_cast<QDate*>(_v)); break;
        case 6: _t->setRecurrence(*reinterpret_cast<Domain::Task::Recurrence*>(_v)); break;
        case 8: _t->setEditingInProgress(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Presentation::EditorModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Presentation::EditorModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Presentation11EditorModelE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "ErrorHandlingModelBase"))
        return static_cast< ErrorHandlingModelBase*>(this);
    return QObject::qt_metacast(_clname);
}

int Presentation::EditorModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void Presentation::EditorModel::taskChanged(const Domain::Task::Ptr & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Presentation::EditorModel::textChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Presentation::EditorModel::titleChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Presentation::EditorModel::doneChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Presentation::EditorModel::startDateChanged(const QDate & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Presentation::EditorModel::dueDateChanged(const QDate & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Presentation::EditorModel::recurrenceChanged(Domain::Task::Recurrence _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
