/****************************************************************************
** Meta object code from reading C++ file 'applicationmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../zanshin-26.08.0/src/presentation/applicationmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'applicationmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12Presentation16ApplicationModelE_t {};
} // unnamed namespace

template <> constexpr inline auto Presentation::ApplicationModel::qt_create_metaobjectdata<qt_meta_tag_ZN12Presentation16ApplicationModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Presentation::ApplicationModel",
        "currentPageChanged",
        "",
        "page",
        "setCurrentPage",
        "setErrorHandler",
        "ErrorHandler*",
        "errorHandler",
        "availableSources",
        "availablePages",
        "currentPage",
        "editor",
        "runningTaskModel",
        "RunningTaskModelInterface*",
        "Presentation::ErrorHandler*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentPageChanged'
        QtMocHelpers::SignalData<void(QObject *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 3 },
        }}),
        // Slot 'setCurrentPage'
        QtMocHelpers::SlotData<void(QObject *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 3 },
        }}),
        // Slot 'setErrorHandler'
        QtMocHelpers::SlotData<void(ErrorHandler *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'availableSources'
        QtMocHelpers::PropertyData<QObject*>(8, QMetaType::QObjectStar, QMC::DefaultPropertyFlags),
        // property 'availablePages'
        QtMocHelpers::PropertyData<QObject*>(9, QMetaType::QObjectStar, QMC::DefaultPropertyFlags),
        // property 'currentPage'
        QtMocHelpers::PropertyData<QObject*>(10, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'editor'
        QtMocHelpers::PropertyData<QObject*>(11, QMetaType::QObjectStar, QMC::DefaultPropertyFlags),
        // property 'runningTaskModel'
        QtMocHelpers::PropertyData<RunningTaskModelInterface*>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'errorHandler'
        QtMocHelpers::PropertyData<Presentation::ErrorHandler*>(7, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ApplicationModel, qt_meta_tag_ZN12Presentation16ApplicationModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Presentation::ApplicationModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Presentation16ApplicationModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Presentation16ApplicationModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12Presentation16ApplicationModelE_t>.metaTypes,
    nullptr
} };

void Presentation::ApplicationModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ApplicationModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentPageChanged((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 1: _t->setCurrentPage((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 2: _t->setErrorHandler((*reinterpret_cast<std::add_pointer_t<ErrorHandler*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ApplicationModel::*)(QObject * )>(_a, &ApplicationModel::currentPageChanged, 0))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Presentation::ErrorHandler* >(); break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< RunningTaskModelInterface* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QObject**>(_v) = _t->availableSources(); break;
        case 1: *reinterpret_cast<QObject**>(_v) = _t->availablePages(); break;
        case 2: *reinterpret_cast<QObject**>(_v) = _t->currentPage(); break;
        case 3: *reinterpret_cast<QObject**>(_v) = _t->editor(); break;
        case 4: *reinterpret_cast<RunningTaskModelInterface**>(_v) = _t->runningTaskModel(); break;
        case 5: *reinterpret_cast<Presentation::ErrorHandler**>(_v) = _t->errorHandler(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setCurrentPage(*reinterpret_cast<QObject**>(_v)); break;
        case 5: _t->setErrorHandler(*reinterpret_cast<Presentation::ErrorHandler**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Presentation::ApplicationModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Presentation::ApplicationModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12Presentation16ApplicationModelE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Presentation::ApplicationModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void Presentation::ApplicationModel::currentPageChanged(QObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
