/********************************************************************************
** Form generated from reading UI file 'filterwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FILTERWIDGET_H
#define UI_FILTERWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_FilterWidget
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLineEdit *filterEdit;
    QToolButton *extensionButton;
    QWidget *extension;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_2;
    QComboBox *sortTypeCombo;
    QToolButton *descendingButton;
    QToolButton *ascendingButton;
    QButtonGroup *sortOrderGroup;

    void setupUi(QWidget *FilterWidget)
    {
        if (FilterWidget->objectName().isEmpty())
            FilterWidget->setObjectName("FilterWidget");
        FilterWidget->resize(400, 300);
        verticalLayout = new QVBoxLayout(FilterWidget);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        filterEdit = new QLineEdit(FilterWidget);
        filterEdit->setObjectName("filterEdit");

        horizontalLayout->addWidget(filterEdit);

        extensionButton = new QToolButton(FilterWidget);
        extensionButton->setObjectName("extensionButton");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("arrow-down-double");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        extensionButton->setIcon(icon);
        extensionButton->setCheckable(true);
        extensionButton->setAutoRaise(true);

        horizontalLayout->addWidget(extensionButton);


        verticalLayout->addLayout(horizontalLayout);

        extension = new QWidget(FilterWidget);
        extension->setObjectName("extension");
        verticalLayout_2 = new QVBoxLayout(extension);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        sortTypeCombo = new QComboBox(extension);
        sortTypeCombo->setObjectName("sortTypeCombo");

        horizontalLayout_2->addWidget(sortTypeCombo);

        descendingButton = new QToolButton(extension);
        sortOrderGroup = new QButtonGroup(FilterWidget);
        sortOrderGroup->setObjectName("sortOrderGroup");
        sortOrderGroup->addButton(descendingButton);
        descendingButton->setObjectName("descendingButton");
        QIcon icon1;
        iconThemeName = QString::fromUtf8("arrow-down");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        descendingButton->setIcon(icon1);
        descendingButton->setCheckable(true);
        descendingButton->setAutoRaise(true);

        horizontalLayout_2->addWidget(descendingButton);

        ascendingButton = new QToolButton(extension);
        sortOrderGroup->addButton(ascendingButton);
        ascendingButton->setObjectName("ascendingButton");
        QIcon icon2;
        iconThemeName = QString::fromUtf8("arrow-up");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon2 = QIcon::fromTheme(iconThemeName);
        } else {
            icon2.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        ascendingButton->setIcon(icon2);
        ascendingButton->setCheckable(true);
        ascendingButton->setChecked(true);
        ascendingButton->setAutoRaise(true);

        horizontalLayout_2->addWidget(ascendingButton);


        verticalLayout_2->addLayout(horizontalLayout_2);


        verticalLayout->addWidget(extension);


        retranslateUi(FilterWidget);
        QObject::connect(extensionButton, &QToolButton::toggled, extension, &QWidget::setVisible);

        QMetaObject::connectSlotsByName(FilterWidget);
    } // setupUi

    void retranslateUi(QWidget *FilterWidget)
    {
        filterEdit->setPlaceholderText(tr2i18n("Filter...", nullptr));
        extensionButton->setText(QString());
#if QT_CONFIG(tooltip)
        descendingButton->setToolTip(tr2i18n("Sort in descending order", nullptr));
#endif // QT_CONFIG(tooltip)
        descendingButton->setText(QString());
#if QT_CONFIG(tooltip)
        ascendingButton->setToolTip(tr2i18n("Sort in ascending order", nullptr));
#endif // QT_CONFIG(tooltip)
        ascendingButton->setText(QString());
        (void)FilterWidget;
    } // retranslateUi

};

namespace Ui {
    class FilterWidget: public Ui_FilterWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FILTERWIDGET_H

