/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // zanshinui.rc
  0x0,0x0,0x1,0x84,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x26,0x4,0xd5,0xb,0x0,0x56,0xd0,0x33,0x1f,0x40,0x8f,0x1b,
  0x8c,0x8d,0x64,0xbb,0x25,0x5d,0xd9,0xf6,0x84,0x2f,0x37,0x40,0x6b,0xdc,0xb0,0x79,
  0xec,0x7b,0xe4,0x1a,0x80,0xb1,0x72,0x8b,0xe2,0x60,0xe7,0x2,0x2d,0x0,0x2a,0x0,
  0x2a,0x0,0x91,0x6b,0xd,0xa4,0x4,0x7d,0xda,0xa1,0x8c,0x9c,0x35,0x6d,0x48,0x91,
  0xbd,0x19,0x7d,0xf8,0xda,0x76,0xd,0xa4,0xef,0x9f,0x40,0x5b,0xc4,0x80,0x48,0x11,
  0xa9,0xc1,0x59,0x7d,0x5c,0xcc,0xd2,0x18,0x8f,0x8,0x44,0xe1,0x58,0x0,0x5c,0xee,
  0xfd,0xba,0x30,0xcc,0xa6,0xe8,0xbf,0x71,0x31,0x96,0x38,0xf3,0x8b,0x23,0x86,0xbf,
  0x9d,0x72,0x9a,0xbe,0xb7,0xd3,0x53,0x5c,0xf1,0x88,0x4d,0x92,0xab,0xc5,0xda,0xe1,
  0x53,0x8,0xb6,0xe0,0x24,0x6e,0x62,0x36,0x7,0x4c,0xc5,0xe9,0x72,0xb2,0x50,0xfe,
  0xa4,0xc5,0xbd,0xf,0x59,0x35,0xfc,0x67,0xe9,0xff,0x18,0x6e,0x95,0xd3,0x61,0xc6,
  0x5e,0x4d,0x32,0xce,0x9f,0x93,0xf6,0x17,0xf9,0x1d,0xe7,0xd,0x3,0x76,0x6d,0x0,
  0xf2,0xca,0x9,0xd,0xe4,0x38,0x8b,0xdc,0x9f,0x7a,0xc6,0xb8,0x92,0x16,0x41,0x3a,
  0x9b,0xaf,0x2,0x5b,0xf,0xff,0xa0,0x4f,0x6b,0xa0,0xa6,0xd,0xf7,0xd2,0x81,0x3e,
  0x5c,0x45,0x8e,0xbc,0x9b,0xe5,0xe,0x71,0xfe,0xf0,0x71,0x45,0xa0,0xf1,0xd,0x52,
  0x4c,0x95,0x90,0x24,0xa5,0xc2,0x30,0x6,0x20,0x46,0x60,0x8c,0x44,0x76,0x1b,0xf4,
  0x24,0x22,0x20,0x5b,0xb3,0xf2,0xa0,0xda,0x20,0x40,0x41,0xde,0xf8,0x8d,0x6e,0x7d,
  0xaf,0x78,0x77,0xba,0xf7,0x37,0xff,0x31,0x56,0x4a,0x9c,0xd5,0x1b,0xb3,0x6a,0xb0,
  0x1,0x85,0xb8,0x2c,0x68,0x39,0x3,0xe5,0x11,0xba,0x2c,0x5d,0x20,0x4c,0xa9,0x2f,
  0x28,0x33,0xb4,0x9e,0x50,0x24,0x93,0x78,0x2e,0xb2,0xc,0x76,0x28,0x56,0xe0,0xfb,
  0xc,0xa5,0x68,0x8c,0x90,0x8c,0x2e,0x77,0x72,0x7b,0xcd,0xdf,0xcb,0x3b,0xca,0x95,
  0x22,0x7f,0x5,0x4c,0x4d,0x30,0x2b,0xf5,0x28,0x5,0xe1,0xde,0x0,0xfc,0xf2,0xba,
  0x18,0xc7,0xb3,0xae,0xe6,0xae,0x1b,0x90,0xba,0x18,0x56,0x91,0xd4,0x9,0x38,0x93,
  0x92,0xef,0xe,0x8d,0xf9,0xa5,0x2c,0xf7,0xb1,0x2c,0x2c,0xb8,0x30,0x46,0x93,0x8a,
  0xf5,0xab,0xd9,0x29,0x60,0x18,0x90,0x92,0xbd,0x6,0xa1,0xe,0x14,0x91,0xd2,0x4f,
  0x84,0x52,0x3,
  
};

static const unsigned char qt_resource_name[] = {
  // kxmlgui5
  0x0,0x8,
  0xf,0x42,0xe5,0x85,
  0x0,0x6b,
  0x0,0x78,0x0,0x6d,0x0,0x6c,0x0,0x67,0x0,0x75,0x0,0x69,0x0,0x35,
    // zanshin
  0x0,0x7,
  0x0,0x85,0x9f,0xfe,
  0x0,0x7a,
  0x0,0x61,0x0,0x6e,0x0,0x73,0x0,0x68,0x0,0x69,0x0,0x6e,
    // zanshinui.rc
  0x0,0xc,
  0x0,0x4b,0x31,0x83,
  0x0,0x7a,
  0x0,0x61,0x0,0x6e,0x0,0x73,0x0,0x68,0x0,0x69,0x0,0x6e,0x0,0x75,0x0,0x69,0x0,0x2e,0x0,0x72,0x0,0x63,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0xa0,0x1a,0xf1,0x8c,0xe8,
  // :/kxmlgui5
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0xa0,0x1a,0xf1,0x8c,0xe8,
  // :/kxmlgui5/zanshin
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0xa0,0x1a,0xf1,0x8c,0xe8,
  // :/kxmlgui5/zanshin/zanshinui.rc
  0x0,0x0,0x0,0x2a,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0xa0,0x1a,0xf1,0x8c,0xe8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_zanshin)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_zanshin)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_zanshin)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_zanshin)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_zanshin)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_zanshin)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
