/****************************************************************************
** Meta object code from reading C++ file 'pageview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../zanshin-26.08.0/src/widgets/pageview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'pageview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Widgets8PageViewE_t {};
} // unnamed namespace

template <> constexpr inline auto Widgets::PageView::qt_create_metaobjectdata<qt_meta_tag_ZN7Widgets8PageViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Widgets::PageView",
        "currentTaskChanged",
        "",
        "Domain::Task::Ptr",
        "task",
        "setModel",
        "model",
        "setRunningTaskModel",
        "Presentation::RunningTaskModelInterface*",
        "setMessageBoxInterface",
        "MessageBoxInterface::Ptr",
        "interface",
        "displayErrorMessage",
        "message",
        "onReturnPressed",
        "onAddItemRequested",
        "onRemoveItemRequested",
        "onPromoteItemRequested",
        "onFilterToggled",
        "show",
        "onCurrentChanged",
        "QModelIndex",
        "current",
        "onRunTaskTriggered",
        "onRunningTaskChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentTaskChanged'
        QtMocHelpers::SignalData<void(const Domain::Task::Ptr &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'setModel'
        QtMocHelpers::SlotData<void(QObject *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 6 },
        }}),
        // Slot 'setRunningTaskModel'
        QtMocHelpers::SlotData<void(Presentation::RunningTaskModelInterface *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 6 },
        }}),
        // Slot 'setMessageBoxInterface'
        QtMocHelpers::SlotData<void(const MessageBoxInterface::Ptr &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'displayErrorMessage'
        QtMocHelpers::SlotData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'onReturnPressed'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onAddItemRequested'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onRemoveItemRequested'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onPromoteItemRequested'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onFilterToggled'
        QtMocHelpers::SlotData<void(bool)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Slot 'onCurrentChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'onRunTaskTriggered'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onRunningTaskChanged'
        QtMocHelpers::SlotData<void(const Domain::Task::Ptr &)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PageView, qt_meta_tag_ZN7Widgets8PageViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Widgets::PageView::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Widgets8PageViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Widgets8PageViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Widgets8PageViewE_t>.metaTypes,
    nullptr
} };

void Widgets::PageView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PageView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentTaskChanged((*reinterpret_cast<std::add_pointer_t<Domain::Task::Ptr>>(_a[1]))); break;
        case 1: _t->setModel((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 2: _t->setRunningTaskModel((*reinterpret_cast<std::add_pointer_t<Presentation::RunningTaskModelInterface*>>(_a[1]))); break;
        case 3: _t->setMessageBoxInterface((*reinterpret_cast<std::add_pointer_t<MessageBoxInterface::Ptr>>(_a[1]))); break;
        case 4: _t->displayErrorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->onReturnPressed(); break;
        case 6: _t->onAddItemRequested(); break;
        case 7: _t->onRemoveItemRequested(); break;
        case 8: _t->onPromoteItemRequested(); break;
        case 9: _t->onFilterToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->onCurrentChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 11: _t->onRunTaskTriggered(); break;
        case 12: _t->onRunningTaskChanged((*reinterpret_cast<std::add_pointer_t<Domain::Task::Ptr>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Domain::Task::Ptr >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Domain::Task::Ptr >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PageView::*)(const Domain::Task::Ptr & )>(_a, &PageView::currentTaskChanged, 0))
            return;
    }
}

const QMetaObject *Widgets::PageView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Widgets::PageView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Widgets8PageViewE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Widgets::PageView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void Widgets::PageView::currentTaskChanged(const Domain::Task::Ptr & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
