/****************************************************************************
** Meta object code from reading C++ file 'editorview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../zanshin-26.08.0/src/widgets/editorview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'editorview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Widgets10EditorViewE_t {};
} // unnamed namespace

template <> constexpr inline auto Widgets::EditorView::qt_create_metaobjectdata<qt_meta_tag_ZN7Widgets10EditorViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Widgets::EditorView",
        "textChanged",
        "",
        "text",
        "titleChanged",
        "title",
        "startDateChanged",
        "start",
        "dueDateChanged",
        "due",
        "doneChanged",
        "done",
        "recurrenceChanged",
        "Domain::Task::Recurrence",
        "recurrence",
        "setModel",
        "model",
        "setRequestFileNameFunction",
        "RequestFileNameFunction",
        "function",
        "onTaskChanged",
        "onTextOrTitleChanged",
        "onStartDateChanged",
        "onDueDateChanged",
        "onDoneChanged",
        "onRecurrenceChanged",
        "onTextEditChanged",
        "onStartEditEntered",
        "onDueEditEntered",
        "onDoneButtonChanged",
        "checked",
        "onStartTodayClicked",
        "onRecurrenceComboChanged",
        "index",
        "onAttachmentSelectionChanged",
        "onAddAttachmentClicked",
        "onRemoveAttachmentClicked",
        "onAttachmentDoubleClicked",
        "QModelIndex"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'textChanged'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'startDateChanged'
        QtMocHelpers::SignalData<void(const QDate &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 7 },
        }}),
        // Signal 'dueDateChanged'
        QtMocHelpers::SignalData<void(const QDate &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 9 },
        }}),
        // Signal 'doneChanged'
        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'recurrenceChanged'
        QtMocHelpers::SignalData<void(Domain::Task::Recurrence)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'setModel'
        QtMocHelpers::SlotData<void(QObject *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 16 },
        }}),
        // Slot 'setRequestFileNameFunction'
        QtMocHelpers::SlotData<void(const RequestFileNameFunction &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'onTaskChanged'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onTextOrTitleChanged'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onStartDateChanged'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onDueDateChanged'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onDoneChanged'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onRecurrenceChanged'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onTextEditChanged'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onStartEditEntered'
        QtMocHelpers::SlotData<void(const QDate &)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QDate, 7 },
        }}),
        // Slot 'onDueEditEntered'
        QtMocHelpers::SlotData<void(const QDate &)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QDate, 9 },
        }}),
        // Slot 'onDoneButtonChanged'
        QtMocHelpers::SlotData<void(bool)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 30 },
        }}),
        // Slot 'onStartTodayClicked'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onRecurrenceComboChanged'
        QtMocHelpers::SlotData<void(int)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 33 },
        }}),
        // Slot 'onAttachmentSelectionChanged'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onAddAttachmentClicked'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onRemoveAttachmentClicked'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onAttachmentDoubleClicked'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 38, 33 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EditorView, qt_meta_tag_ZN7Widgets10EditorViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Widgets::EditorView::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Widgets10EditorViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Widgets10EditorViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Widgets10EditorViewE_t>.metaTypes,
    nullptr
} };

void Widgets::EditorView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EditorView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->textChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->titleChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->startDateChanged((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 3: _t->dueDateChanged((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 4: _t->doneChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->recurrenceChanged((*reinterpret_cast<std::add_pointer_t<Domain::Task::Recurrence>>(_a[1]))); break;
        case 6: _t->setModel((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 7: _t->setRequestFileNameFunction((*reinterpret_cast<std::add_pointer_t<RequestFileNameFunction>>(_a[1]))); break;
        case 8: _t->onTaskChanged(); break;
        case 9: _t->onTextOrTitleChanged(); break;
        case 10: _t->onStartDateChanged(); break;
        case 11: _t->onDueDateChanged(); break;
        case 12: _t->onDoneChanged(); break;
        case 13: _t->onRecurrenceChanged(); break;
        case 14: _t->onTextEditChanged(); break;
        case 15: _t->onStartEditEntered((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 16: _t->onDueEditEntered((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 17: _t->onDoneButtonChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->onStartTodayClicked(); break;
        case 19: _t->onRecurrenceComboChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->onAttachmentSelectionChanged(); break;
        case 21: _t->onAddAttachmentClicked(); break;
        case 22: _t->onRemoveAttachmentClicked(); break;
        case 23: _t->onAttachmentDoubleClicked((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (EditorView::*)(const QString & )>(_a, &EditorView::textChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditorView::*)(const QString & )>(_a, &EditorView::titleChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditorView::*)(const QDate & )>(_a, &EditorView::startDateChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditorView::*)(const QDate & )>(_a, &EditorView::dueDateChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditorView::*)(bool )>(_a, &EditorView::doneChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditorView::*)(Domain::Task::Recurrence )>(_a, &EditorView::recurrenceChanged, 5))
            return;
    }
}

const QMetaObject *Widgets::EditorView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Widgets::EditorView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Widgets10EditorViewE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Widgets::EditorView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 24;
    }
    return _id;
}

// SIGNAL 0
void Widgets::EditorView::textChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Widgets::EditorView::titleChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Widgets::EditorView::startDateChanged(const QDate & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Widgets::EditorView::dueDateChanged(const QDate & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Widgets::EditorView::doneChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Widgets::EditorView::recurrenceChanged(Domain::Task::Recurrence _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
