/****************************************************************************
** Meta object code from reading C++ file 'availablepagesview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../zanshin-26.08.0/src/widgets/availablepagesview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'availablepagesview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Widgets18AvailablePagesViewE_t {};
} // unnamed namespace

template <> constexpr inline auto Widgets::AvailablePagesView::qt_create_metaobjectdata<qt_meta_tag_ZN7Widgets18AvailablePagesViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Widgets::AvailablePagesView",
        "currentPageChanged",
        "",
        "page",
        "setModel",
        "model",
        "setProjectSourcesModel",
        "QAbstractItemModel*",
        "sources",
        "setDefaultProjectSource",
        "Domain::DataSource::Ptr",
        "source",
        "setProjectDialogFactory",
        "ProjectDialogFactory",
        "factory",
        "setQuickSelectDialogFactory",
        "QuickSelectDialogFactory",
        "setMessageBoxInterface",
        "MessageBoxInterface::Ptr",
        "interface",
        "onCurrentChanged",
        "QModelIndex",
        "current",
        "onAddProjectTriggered",
        "onAddContextTriggered",
        "onRemoveTriggered",
        "onGoPreviousTriggered",
        "onGoNextTriggered",
        "onGoToTriggered",
        "onInitTimeout"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentPageChanged'
        QtMocHelpers::SignalData<void(QObject *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 3 },
        }}),
        // Slot 'setModel'
        QtMocHelpers::SlotData<void(QObject *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 5 },
        }}),
        // Slot 'setProjectSourcesModel'
        QtMocHelpers::SlotData<void(QAbstractItemModel *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'setDefaultProjectSource'
        QtMocHelpers::SlotData<void(const Domain::DataSource::Ptr &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'setProjectDialogFactory'
        QtMocHelpers::SlotData<void(const ProjectDialogFactory &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'setQuickSelectDialogFactory'
        QtMocHelpers::SlotData<void(const QuickSelectDialogFactory &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 14 },
        }}),
        // Slot 'setMessageBoxInterface'
        QtMocHelpers::SlotData<void(const MessageBoxInterface::Ptr &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'onCurrentChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'onAddProjectTriggered'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onAddContextTriggered'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onRemoveTriggered'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onGoPreviousTriggered'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onGoNextTriggered'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onGoToTriggered'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onInitTimeout'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AvailablePagesView, qt_meta_tag_ZN7Widgets18AvailablePagesViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Widgets::AvailablePagesView::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Widgets18AvailablePagesViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Widgets18AvailablePagesViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Widgets18AvailablePagesViewE_t>.metaTypes,
    nullptr
} };

void Widgets::AvailablePagesView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AvailablePagesView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentPageChanged((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 1: _t->setModel((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 2: _t->setProjectSourcesModel((*reinterpret_cast<std::add_pointer_t<QAbstractItemModel*>>(_a[1]))); break;
        case 3: _t->setDefaultProjectSource((*reinterpret_cast<std::add_pointer_t<Domain::DataSource::Ptr>>(_a[1]))); break;
        case 4: _t->setProjectDialogFactory((*reinterpret_cast<std::add_pointer_t<ProjectDialogFactory>>(_a[1]))); break;
        case 5: _t->setQuickSelectDialogFactory((*reinterpret_cast<std::add_pointer_t<QuickSelectDialogFactory>>(_a[1]))); break;
        case 6: _t->setMessageBoxInterface((*reinterpret_cast<std::add_pointer_t<MessageBoxInterface::Ptr>>(_a[1]))); break;
        case 7: _t->onCurrentChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 8: _t->onAddProjectTriggered(); break;
        case 9: _t->onAddContextTriggered(); break;
        case 10: _t->onRemoveTriggered(); break;
        case 11: _t->onGoPreviousTriggered(); break;
        case 12: _t->onGoNextTriggered(); break;
        case 13: _t->onGoToTriggered(); break;
        case 14: _t->onInitTimeout(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Domain::DataSource::Ptr >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AvailablePagesView::*)(QObject * )>(_a, &AvailablePagesView::currentPageChanged, 0))
            return;
    }
}

const QMetaObject *Widgets::AvailablePagesView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Widgets::AvailablePagesView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Widgets18AvailablePagesViewE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Widgets::AvailablePagesView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void Widgets::AvailablePagesView::currentPageChanged(QObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
